@@ -16,37 +16,26 @@
 #'
 #' to_dwc("record_id", "date_time", "scientific_name")
 #' @export
-
 to_dwc <- function(...) {
-
   l <- list(...)
-
   to(l, "translated_var", "dwc")
-
 }
 
 #' @rdname to_dwc
 #' @export
-
 to_native <- function(...) {
-
   l <- list(...)
-
   to(l, "dwc", "translated_var")
-
 }
 
 #' @rdname to_dwc
 #' @export
-
 from_schema <- function(
   ...,
-  to = c("native", "dwc", "short"),
+  to = c("native", "dwc"),
   file = c("none", "citable", "lite")
 ) {
-
   nms <- c(...)
-
   nms <- make.names(nms)
 
   vars <- switch(
@@ -59,42 +48,30 @@ from_schema <- function(
   to <- switch(
     match.arg(to),
     native = "translated_var",
-    dwc = "dwc",
-    short = "shrtnm"
+    dwc = "dwc"
   )
 
   vars[nms, to]
-
 }
 
 #' @noRd
-
 to <- function(
   x,
   from,
   to
 ) {
-
   x <- unlist(x)
 
   var_names <- sysdata(list(which = "var_names"))
-
   vars_to <- var_names[[to]]
-
   vars_from <- var_names[[from]]
-
   vars_to <- c(vars_to, "default_vars")
 
   ind <- !x %in% vars_to
-
   xx <- x[ind]
-
   xx <- match(xx, vars_from)
-
   xx <- var_names[xx, to]
-
   x[ind] <- xx
 
   x
-
 }
